#!/usr/bin/env bash

############
# This script initializes the schemas in the UBS DB.
#
# Important - this assumes it is run inside of the ubs_db_migrations container. Usage: bash /db/scripts/init.sh.
#
# For environment-specific initializes make init scripts per environment.
# Note that the environment variables must be set!
############

# Exit immediately on failure
set -e

# Create connection string
if [ -z "$RDS_SSLROOTCERT" ] # If not set
then
    PSQL_CONN="postgresql://${RDS_USER}:${RDS_PASSWORD}@${RDS_WRITER_HOST}:${RDS_PORT}/${RDS_DB}?sslmode=${RDS_SSLMODE}"
else
    PSQL_CONN="postgresql://${RDS_USER}:${RDS_PASSWORD}@${RDS_WRITER_HOST}:${RDS_PORT}/${RDS_DB}?sslmode=${RDS_SSLMODE}&sslrootcert=${RDS_SSLROOTCERT}"
fi

# Perform common init
for f in /db/initializations/*
do
    # Match SQL scripts prefixed with numerics
    FILE_NAME="$(echo $f | sed -n '/^\/db\/initializations\/[0-9]\{2\}-.*\.sql$/p')"
    if [ ! -z "$FILE_NAME" ]
    then
        # Execute the SQL script
        psql ${PSQL_CONN} -f ${FILE_NAME}
    fi
done
